@@ -923,7 +923,7 @@ class Date(Time):
 
         Documentation of Date:
 
-     • __init__ -> Can be called empty to initialize to 0
+     • __init__ -> Can be called empty to initialize to 12625459200000000000 nanoseconds
      • by_time() -> static method allowing to convert a Time into a Date
      • by_datetime_datetime() -> static method allowing to convert a datetime.datetime into Date
      • by_datetime_date() -> static method allowing to convert a datetime.date into Date
@@ -946,7 +946,9 @@ class Date(Time):
 """
 
     @staticmethod
-    def by_time(time):
+    def by_time(time: Time):
+        if time.get('nanosecond') < 12625459200000000000:
+            return ValueError('Value too small.')
         return Date(time[1], time[2], time[3], time[4], time[5], time[6], time[7], time[8], time[9], time[0], time[10])
 
     @staticmethod
@@ -955,26 +957,40 @@ class Date(Time):
 
     @staticmethod
     def by_datetime_date(date: datetime.date):
-        return Date(date.year, date.month, date.day)
+        return Date.by_time(Time.by_datetime_date(date))
 
     @staticmethod
     def by_datetime_time(date: datetime.time):
-        return Date(0, 0, 0, date.hour, date.minute, date.second,
-                    date.microsecond // 1000, date.microsecond % 1000)
+        return Date.by_time(Time.by_datetime_time(date))
 
     @staticmethod
     def by_datetime_datetime(date: datetime.datetime):
-        return Date(date.year, date.month, date.day, date.hour, date.minute, date.second,
-                    date.microsecond // 1000, date.microsecond % 1000)
+        return Date.by_time(Time.by_datetime_datetime(date))
 
     @staticmethod
     def now():
-        return Date(
-            # time_ns() -> UTC time since epoch + compensation to arrive at today
-            nanosecond=(time_ns() + Date(year=1970).get('nanosecond') + Time(
-                minute=DELTA[os.popen('tzutil /g').read()]).get('nanosecond')),
-            name="NOW"
-        )
+        if os.name == 'posix':
+            nano_time_now = (
+                    time_ns() + Date(year=1970, month=1, day=1).get('nanosecond') +
+                    Time(second=168000).get('nanosecond') +
+                    Time(minute=int(os.popen('date +%z').read()[:-1])).get('nanosecond')
+            )
+            return Date(
+                # time_ns() -> UTC time since epoch + compensation to arrive at today
+                nanosecond=nano_time_now,
+                name="NOW"
+            )
+        else:
+            nano_time_now = (
+                    time_ns() + Date(year=1970, month=1, day=1).get('nanosecond') +
+                    Time(second=168000).get('nanosecond') +
+                    Time(minute=DELTA[os.popen('tzutil /g').read()]).get('nanosecond')
+                )
+            return Date(
+                # time_ns() -> UTC time since epoch + compensation to arrive at today
+                nanosecond=nano_time_now,
+                name="NOW"
+            )
 
     def __init__(
             self,
@@ -1278,29 +1294,3 @@ def set_language(language: str):
         _LANGUAGE = code
     else:
         raise ValueError(f'{code} is not in supported languages')
-
-
-if __name__ == '__main__':
-    if Date.now().get_value('month') > 9 or (Date.now().get_value('month') == 9 and Date.now().get_value('day') > 7):
-        birthday = Date(year=Date.now().get_value('year') + 1, month=9, day=7, hour=20, minute=50)
-    else:
-        birthday = Date(year=Date.now().get_value('year'), month=9, day=7, hour=20, minute=50)
-
-    test: Time
-
-    print(f"{str(Date.now())}\n"
-          f"{str(birthday.countdown())}\n"
-          f"{str(Date.now() + birthday.countdown())}\n\n")
-    test = Date.now() + birthday.countdown()
-    print(f"My birthday is in {str(birthday.countdown()).split(':')[1][1:]}\n"
-          f"the {str(Date.by_time(test))}\n")
-
-    birthday.set_language('fr')
-    test.set_language('fr')
-    print(f"Mon anniversaire est dans {str(birthday.countdown()).split(':')[1][1:]}\n"
-          f"le {str(Date.by_time(test))}\n")
-
-    birthday.set_language('sp')
-    test.set_language('sp')
-    print(f"Mi cumpleaños es en {str(birthday.countdown()).split(':')[1][1:]}\n"
-          f"la {str(Date.by_time(test))}\n")
